==> dif-database-repository-2.6.1-8-20200421.173538-1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/IRGPDService.java <==
package pt.digitalis.dif.dem.managers.impl.model;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.utils.common.IBeanAttributes;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IDataConsentDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsent;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IDataConsentUserDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsentUser;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IDataConsentReviewDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsentReview;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IDataConsentTransDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsentTrans;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IUserDataConsentDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.UserDataConsent;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IUserDataRequestDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.UserDataRequest;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IUserDataRequestCommentDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.UserDataRequestComment;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public interface IRGPDService {

	/**
	 * Obtains a new DataConsent DAO
	 *
	 * @return A new IDataConsentDAO
	 */
    public IDataConsentDAO getDataConsentDAO();

    /**
     * Obtains a new DataSet for the DataConsent entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<DataConsent> getDataConsentDataSet();

	/**
	 * Obtains a new DataConsentUser DAO
	 *
	 * @return A new IDataConsentUserDAO
	 */
    public IDataConsentUserDAO getDataConsentUserDAO();

    /**
     * Obtains a new DataSet for the DataConsentUser entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<DataConsentUser> getDataConsentUserDataSet();

	/**
	 * Obtains a new DataConsentReview DAO
	 *
	 * @return A new IDataConsentReviewDAO
	 */
    public IDataConsentReviewDAO getDataConsentReviewDAO();

    /**
     * Obtains a new DataSet for the DataConsentReview entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<DataConsentReview> getDataConsentReviewDataSet();

	/**
	 * Obtains a new DataConsentTrans DAO
	 *
	 * @return A new IDataConsentTransDAO
	 */
    public IDataConsentTransDAO getDataConsentTransDAO();

    /**
     * Obtains a new DataSet for the DataConsentTrans entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<DataConsentTrans> getDataConsentTransDataSet();

	/**
	 * Obtains a new UserDataConsent DAO
	 *
	 * @return A new IUserDataConsentDAO
	 */
    public IUserDataConsentDAO getUserDataConsentDAO();

    /**
     * Obtains a new DataSet for the UserDataConsent entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<UserDataConsent> getUserDataConsentDataSet();

	/**
	 * Obtains a new UserDataRequest DAO
	 *
	 * @return A new IUserDataRequestDAO
	 */
    public IUserDataRequestDAO getUserDataRequestDAO();

    /**
     * Obtains a new DataSet for the UserDataRequest entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<UserDataRequest> getUserDataRequestDataSet();

	/**
	 * Obtains a new UserDataRequestComment DAO
	 *
	 * @return A new IUserDataRequestCommentDAO
	 */
    public IUserDataRequestCommentDAO getUserDataRequestCommentDAO();

    /**
     * Obtains a new DataSet for the UserDataRequestComment entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<UserDataRequestComment> getUserDataRequestCommentDataSet();


    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz);

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName);
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/IRGPDService.java <==
package pt.digitalis.dif.dem.managers.impl.model;

import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.utils.common.IBeanAttributes;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsent;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsentUser;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsentReview;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsentTrans;
import pt.digitalis.dif.dem.managers.impl.model.data.UserDataConsent;
import pt.digitalis.dif.dem.managers.impl.model.data.UserDataRequest;
import pt.digitalis.dif.dem.managers.impl.model.data.UserDataRequestComment;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public interface IRGPDService {

    /**
     * Obtains a new DataSet for the DataConsent entity
     *
     * @return A new IDataSet instance
     */
    public HibernateDataSet<DataConsent> getDataConsentDataSet();

    /**
     * Obtains a new DataSet for the DataConsentUser entity
     *
     * @return A new IDataSet instance
     */
    public HibernateDataSet<DataConsentUser> getDataConsentUserDataSet();

    /**
     * Obtains a new DataSet for the DataConsentReview entity
     *
     * @return A new IDataSet instance
     */
    public HibernateDataSet<DataConsentReview> getDataConsentReviewDataSet();

    /**
     * Obtains a new DataSet for the DataConsentTrans entity
     *
     * @return A new IDataSet instance
     */
    public HibernateDataSet<DataConsentTrans> getDataConsentTransDataSet();

    /**
     * Obtains a new DataSet for the UserDataConsent entity
     *
     * @return A new IDataSet instance
     */
    public HibernateDataSet<UserDataConsent> getUserDataConsentDataSet();

    /**
     * Obtains a new DataSet for the UserDataRequest entity
     *
     * @return A new IDataSet instance
     */
    public HibernateDataSet<UserDataRequest> getUserDataRequestDataSet();

    /**
     * Obtains a new DataSet for the UserDataRequestComment entity
     *
     * @return A new IDataSet instance
     */
    public HibernateDataSet<UserDataRequestComment> getUserDataRequestCommentDataSet();


    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz);

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName);
}
